Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1382)

Unified Diff: chrome/browser/profiles/profile_impl.h

Issue 1913373002: Revert "Refactor ProfileInfoCache in most of c/b/profiles" (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/profiles/profile_avatar_icon_util.cc ('k') | chrome/browser/profiles/profile_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/profiles/profile_impl.h
diff --git a/chrome/browser/profiles/profile_impl.h b/chrome/browser/profiles/profile_impl.h
index 515485afa602e46ff88327ac9ee3d81eb288a2f2..1c7a2967c9bec0e1048a8f891a78b328ecf18672 100644
--- a/chrome/browser/profiles/profile_impl.h
+++ b/chrome/browser/profiles/profile_impl.h
@@ -178,11 +178,11 @@ class ProfileImpl : public Profile {
void EnsureSessionServiceCreated();
#endif
- // Updates the ProfileAttributesStorage with the data from this profile.
- void UpdateSupervisedUserIdInStorage();
- void UpdateNameInStorage();
- void UpdateAvatarInStorage();
- void UpdateIsEphemeralInStorage();
+ // Updates the ProfileInfoCache with data from this profile.
+ void UpdateProfileSupervisedUserIdCache();
+ void UpdateProfileNameCache();
+ void UpdateProfileAvatarCache();
+ void UpdateProfileIsEphemeralCache();
void GetCacheParameters(bool is_media_context,
base::FilePath* cache_path,
« no previous file with comments | « chrome/browser/profiles/profile_avatar_icon_util.cc ('k') | chrome/browser/profiles/profile_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698